@@ -724,6 +724,18 @@ class ExpectationConfiguration(SerializableDictDot):
                 "catch_exceptions": False,
             },
         },
+        "expect_multicolumn_sum_to_equal": {
+            "domain_kwargs": ["column_list", "row_condition", "condition_parser"],
+            "success_kwargs": ["sum_total", "ignore_row_if"],
+            "default_kwarg_values": {
+                "row_condition": None,
+                "condition_parser": "pandas",
+                "ignore_row_if": "all_values_are_missing",
+                "result_format": "BASIC",
+                "include_config": True,
+                "catch_exceptions": False,
+            },
+        },
         "_expect_column_values_to_be_of_type__aggregate": {
             "domain_kwargs": ["column", "row_condition", "condition_parser"],
             "success_kwargs": ["type_", "mostly"],
