@@ -281,22 +281,31 @@ class DataConnectorConfig(DictDot):
         self,
         class_name,
         module_name=None,
+        credentials=None,
         assets=None,
         base_directory=None,
         glob_directive=None,
         default_regex=None,
         batch_identifiers=None,
-        bucket=None,
-        prefix=None,
-        delimiter=None,
-        max_keys=None,
-        boto3_options=None,
         sorters=None,
         batch_spec_passthrough=None,
+        # S3
+        boto3_options=None,
+        bucket=None,
+        prefix=None,
+        max_keys=None,
+        # Azure
+        azure_options=None,
+        container=None,
+        name_starts_with=None,
+        # Both S3/Azure
+        delimiter=None,
         **kwargs,
     ):
         self._class_name = class_name
         self._module_name = module_name
+        if credentials is not None:
+            self.credentials = credentials
         if assets is not None:
             self.assets = assets
         if base_directory is not None:
@@ -307,20 +316,33 @@ class DataConnectorConfig(DictDot):
             self.default_regex = default_regex
         if batch_identifiers is not None:
             self.batch_identifiers = batch_identifiers
-        if bucket is not None:
-            self.bucket = bucket
-        if prefix is not None:
-            self.prefix = prefix
-        if delimiter is not None:
-            self.delimiter = delimiter
-        if max_keys is not None:
-            self.max_keys = max_keys
-        if boto3_options is not None:
-            self.boto3_options = boto3_options
         if sorters is not None:
             self.sorters = sorters
         if batch_spec_passthrough is not None:
             self.batch_spec_passthrough = batch_spec_passthrough
+
+        # S3
+        if boto3_options is not None:
+            self.boto3_options = boto3_options
+        if bucket is not None:
+            self.bucket = bucket
+        if prefix is not None:
+            self.prefix = prefix
+        if max_keys is not None:
+            self.max_keys = max_keys
+
+        # Azure
+        if azure_options is not None:
+            self.azure_options = azure_options
+        if container is not None:
+            self.container = container
+        if name_starts_with is not None:
+            self.name_starts_with = name_starts_with
+
+        # Both S3/Azure
+        if delimiter is not None:
+            self.delimiter = delimiter
+
         for k, v in kwargs.items():
             setattr(self, k, v)
 
@@ -355,16 +377,29 @@ class DataConnectorConfigSchema(Schema):
         allow_none=True,
     )
     default_regex = fields.Dict(required=False, allow_none=True)
+    credentials = fields.Raw(required=False, allow_none=True)
     batch_identifiers = fields.List(
         cls_or_instance=fields.Str(), required=False, allow_none=True
     )
-    bucket = fields.String(required=False, allow_none=True)
-    prefix = fields.String(required=False, allow_none=True)
-    delimiter = fields.String(required=False, allow_none=True)
-    max_keys = fields.Integer(required=False, allow_none=True)
+
+    # S3
     boto3_options = fields.Dict(
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
     )
+    bucket = fields.String(required=False, allow_none=True)
+    prefix = fields.String(required=False, allow_none=True)
+    max_keys = fields.Integer(required=False, allow_none=True)
+
+    # Azure
+    azure_options = fields.Dict(
+        keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
+    )
+    container = fields.String(required=False, allow_none=True)
+    name_starts_with = fields.String(required=False, allow_none=True)
+
+    # Both S3/Azure
+    delimiter = fields.String(required=False, allow_none=True)
+
     data_asset_name_prefix = fields.String(required=False, allow_none=True)
     data_asset_name_suffix = fields.String(required=False, allow_none=True)
     include_schema_name = fields.Boolean(required=False, allow_none=True)
@@ -393,11 +428,13 @@ class DataConnectorConfigSchema(Schema):
                 "ConfiguredAssetFilesystemDataConnector",
                 "InferredAssetS3DataConnector",
                 "ConfiguredAssetS3DataConnector",
+                "InferredAssetAzureDataConnector",
+                "ConfiguredAssetAzureDataConnector",
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
                 f"""Your current configuration uses one or more keys in a data connector, that are required only by a
-subclass of the FilePathDataConnector class (your data conntector is "{data['class_name']}").  Please update your
+subclass of the FilePathDataConnector class (your data connector is "{data['class_name']}").  Please update your
 configuration to continue.
                 """
             )
@@ -410,16 +447,26 @@ configuration to continue.
         ):
             raise ge_exceptions.InvalidConfigError(
                 f"""Your current configuration uses one or more keys in a data connector, that are required only by a
-filesystem type of the data connector (your data conntector is "{data['class_name']}").  Please update your
+filesystem type of the data connector (your data connector is "{data['class_name']}").  Please update your
 configuration to continue.
                 """
             )
-        if (
-            "bucket" in data
-            or "prefix" in data
-            or "delimiter" in data
-            or "max_keys" in data
-        ) and not (
+        if ("delimiter" in data) and not (
+            data["class_name"]
+            in [
+                "InferredAssetS3DataConnector",
+                "ConfiguredAssetS3DataConnector",
+                "InferredAssetAzureDataConnector",
+                "ConfiguredAssetAzureDataConnector",
+            ]
+        ):
+            raise ge_exceptions.InvalidConfigError(
+                f"""Your current configuration uses one or more keys in a data connector, that are required only by an
+S3/Azure type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
+continue.
+                """
+            )
+        if ("bucket" in data or "prefix" in data or "max_keys" in data) and not (
             data["class_name"]
             in [
                 "InferredAssetS3DataConnector",
@@ -428,10 +475,36 @@ configuration to continue.
         ):
             raise ge_exceptions.InvalidConfigError(
                 f"""Your current configuration uses one or more keys in a data connector, that are required only by an
-S3 type of the data connector (your data conntector is "{data['class_name']}").  Please update your configuration to
+S3 type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
 continue.
                 """
             )
+        if (
+            "azure_options" in data or "container" in data or "name_starts_with" in data
+        ) and not (
+            data["class_name"]
+            in [
+                "InferredAssetAzureDataConnector",
+                "ConfiguredAssetAzureDataConnector",
+            ]
+        ):
+            raise ge_exceptions.InvalidConfigError(
+                f"""Your current configuration uses one or more keys in a data connector, that are required only by an
+Azure type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
+continue.
+                    """
+            )
+        if "azure_options" in data and data["class_name"] in [
+            "InferredAssetAzureDataConnector",
+            "ConfiguredAssetAzureDataConnector",
+        ]:
+            azure_options = data["azure_options"]
+            if not (("conn_str" in azure_options) ^ ("account_url" in azure_options)):
+                raise ge_exceptions.InvalidConfigError(
+                    f"""Your current configuration is either missing methods of authentication or is using too many for the Azure type of data connector.
+                    You must only select one between `conn_str` and `account_url`. Please update your configuration to continue.
+                    """
+                )
         if (
             "data_asset_name_prefix" in data
             or "data_asset_name_suffix" in data
@@ -452,7 +525,7 @@ continue.
         ):
             raise ge_exceptions.InvalidConfigError(
                 f"""Your current configuration uses one or more keys in a data connector, that are required only by an
-SQL type of the data connector (your data conntector is "{data['class_name']}").  Please update your configuration to
+SQL type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
 continue.
                 """
             )
@@ -474,6 +547,7 @@ class ExecutionEngineConfig(DictDot):
         credentials=None,
         spark_config=None,
         boto3_options=None,
+        azure_options=None,
         **kwargs,
     ):
         self._class_name = class_name
@@ -490,6 +564,8 @@ class ExecutionEngineConfig(DictDot):
             self.spark_config = spark_config
         if boto3_options is not None:
             self.boto3_options = boto3_options
+        if azure_options is not None:
+            self.azure_options = azure_options
         for k, v in kwargs.items():
             setattr(self, k, v)
 
@@ -518,6 +594,9 @@ class ExecutionEngineConfigSchema(Schema):
     boto3_options = fields.Dict(
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
     )
+    azure_options = fields.Dict(
+        keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
+    )
     caching = fields.Boolean(required=False, allow_none=True)
     batch_spec_defaults = fields.Dict(required=False, allow_none=True)
 
@@ -565,6 +644,7 @@ class DatasourceConfig(DictDot):
         introspection=None,
         tables=None,
         boto3_options=None,
+        azure_options=None,
         reader_method=None,
         reader_options=None,
         limit=None,
@@ -609,6 +689,8 @@ class DatasourceConfig(DictDot):
             self.tables = tables
         if boto3_options is not None:
             self.boto3_options = boto3_options
+        if azure_options is not None:
+            self.azure_options = azure_options
         if reader_method is not None:
             self.reader_method = reader_method
         if reader_options is not None:
@@ -658,6 +740,9 @@ class DatasourceConfigSchema(Schema):
     boto3_options = fields.Dict(
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
     )
+    azure_options = fields.Dict(
+        keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
+    )
     reader_method = fields.String(required=False, allow_none=True)
     reader_options = fields.Dict(
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
@@ -1464,7 +1549,7 @@ class DatabaseStoreBackendDefaults(BaseStoreBackendDefaults):
         # Initialize base defaults
         super().__init__()
 
-        # Use default credentials if seprate credentials not supplied for expectations_store and validations_store
+        # Use default credentials if separate credentials not supplied for expectations_store and validations_store
         if expectations_store_credentials is None:
             expectations_store_credentials = default_credentials
         if validations_store_credentials is None:
@@ -1932,6 +2017,10 @@ class CheckpointConfig(BaseYamlConfig):
     def batch_request(self):
         return self._batch_request
 
+    @batch_request.setter
+    def batch_request(self, value: dict):
+        self._batch_request = value
+
     @property
     def expectation_suite_name(self):
         return self._expectation_suite_name
