@@ -3,6 +3,7 @@ import datetime
 import hashlib
 import logging
 import uuid
+from functools import reduce
 from typing import Any, Callable, Dict, Iterable, Optional, Tuple, Union
 
 from great_expectations.core.batch import BatchMarkers
@@ -315,12 +316,118 @@ Please check your config."""
                 {"reader_method": reader_method},
             )
 
+    def get_domain_records(
+        self,
+        domain_kwargs: dict,
+    ) -> DataFrame:
+        """
+        Uses the given domain kwargs (which include row_condition, condition_parser, and ignore_row_if directives) to
+        obtain and/or query a batch. Returns in the format of a Spark DataFrame.
+
+        Args:
+            domain_kwargs (dict) - A dictionary consisting of the domain kwargs specifying which data to obtain
+
+        Returns:
+            A DataFrame (the data on which to compute)
+        """
+        table = domain_kwargs.get("table", None)
+        if table:
+            raise ValueError(
+                "SparkDFExecutionEngine does not currently support multiple named tables."
+            )
+
+        batch_id = domain_kwargs.get("batch_id")
+        if batch_id is None:
+            # We allow no batch id specified if there is only one batch
+            if self.active_batch_data:
+                data = self.active_batch_data.dataframe
+            else:
+                raise ValidationError(
+                    "No batch is specified, but could not identify a loaded batch."
+                )
+        else:
+            if batch_id in self.loaded_batch_data_dict:
+                data = self.loaded_batch_data_dict[batch_id].dataframe
+            else:
+                raise ValidationError(f"Unable to find batch with batch_id {batch_id}")
+
+        # Filtering by row condition.
+        row_condition = domain_kwargs.get("row_condition", None)
+        if row_condition:
+            condition_parser = domain_kwargs.get("condition_parser", None)
+            if condition_parser == "spark":
+                data = data.filter(row_condition)
+            elif condition_parser == "great_expectations__experimental__":
+                parsed_condition = parse_condition_to_spark(row_condition)
+                data = data.filter(parsed_condition)
+            else:
+                raise GreatExpectationsError(
+                    f"unrecognized condition_parser {str(condition_parser)} for Spark execution engine"
+                )
+
+        if "column" in domain_kwargs:
+            return data
+
+        if (
+            "column_A" in domain_kwargs
+            and "column_B" in domain_kwargs
+            and "ignore_row_if" in domain_kwargs
+        ):
+            # noinspection PyPep8Naming
+            column_A_name = domain_kwargs["column_A"]
+            # noinspection PyPep8Naming
+            column_B_name = domain_kwargs["column_B"]
+
+            ignore_row_if = domain_kwargs["ignore_row_if"]
+            if ignore_row_if == "both_values_are_missing":
+                ignore_condition = (
+                    F.col(column_A_name).isNull() & F.col(column_B_name).isNull()
+                )
+                data = data.filter(~ignore_condition)
+            elif ignore_row_if == "either_value_is_missing":
+                ignore_condition = (
+                    F.col(column_A_name).isNull() | F.col(column_B_name).isNull()
+                )
+                data = data.filter(~ignore_condition)
+            else:
+                if ignore_row_if != "never":
+                    raise ValueError(
+                        f'Unrecognized value of ignore_row_if ("{ignore_row_if}").'
+                    )
+
+            return data
+
+        if "column_list" in domain_kwargs and "ignore_row_if" in domain_kwargs:
+            column_list = domain_kwargs["column_list"]
+            ignore_row_if = domain_kwargs["ignore_row_if"]
+            if ignore_row_if == "all_values_are_missing":
+                ignore_condition = reduce(
+                    lambda column_a, column_b: column_a.isNull() & column_b.isNull(),
+                    map(F.col, column_list),
+                )
+                data = data.filter(~ignore_condition)
+            elif ignore_row_if == "any_value_is_missing":
+                ignore_condition = reduce(
+                    lambda column_a, column_b: column_a.isNull() | column_b.isNull(),
+                    map(F.col, column_list),
+                )
+                data = data.filter(~ignore_condition)
+            else:
+                if ignore_row_if != "never":
+                    raise ValueError(
+                        f'Unrecognized value of ignore_row_if ("{ignore_row_if}").'
+                    )
+
+            return data
+
+        return data
+
     def get_compute_domain(
         self,
         domain_kwargs: dict,
         domain_type: Union[str, MetricDomainTypes],
         accessor_keys: Optional[Iterable[str]] = None,
-    ) -> Tuple["pyspark.sql.DataFrame", dict, dict]:
+    ) -> Tuple[DataFrame, dict, dict]:
         """Uses a given batch dictionary and domain kwargs (which include a row condition and a condition parser)
         to obtain and/or query a batch. Returns in the format of a Pandas Series if only a single column is desired,
         or otherwise a Data Frame.
@@ -341,24 +448,12 @@ Please check your config."""
               - a dictionary of accessor_domain_kwargs, describing any accessors needed to
                 identify the domain within the compute domain
         """
+        data = self.get_domain_records(
+            domain_kwargs=domain_kwargs,
+        )
         # Extracting value from enum if it is given for future computation
         domain_type = MetricDomainTypes(domain_type)
 
-        batch_id = domain_kwargs.get("batch_id")
-        if batch_id is None:
-            # We allow no batch id specified if there is only one batch
-            if self.active_batch_data:
-                data = self.active_batch_data.dataframe
-            else:
-                raise ValidationError(
-                    "No batch is specified, but could not identify a loaded batch."
-                )
-        else:
-            if batch_id in self.loaded_batch_data_dict:
-                data = self.loaded_batch_data_dict[batch_id].dataframe
-            else:
-                raise ValidationError(f"Unable to find batch with batch_id {batch_id}")
-
         compute_domain_kwargs = copy.deepcopy(domain_kwargs)
         accessor_domain_kwargs = dict()
         table = domain_kwargs.get("table", None)
@@ -367,19 +462,6 @@ Please check your config."""
                 "SparkDFExecutionEngine does not currently support multiple named tables."
             )
 
-        row_condition = domain_kwargs.get("row_condition", None)
-        if row_condition:
-            condition_parser = domain_kwargs.get("condition_parser", None)
-            if condition_parser == "spark":
-                data = data.filter(row_condition)
-            elif condition_parser == "great_expectations__experimental__":
-                parsed_condition = parse_condition_to_spark(row_condition)
-                data = data.filter(parsed_condition)
-            else:
-                raise GreatExpectationsError(
-                    f"unrecognized condition_parser {str(condition_parser)}for Spark execution engine"
-                )
-
         # Warning user if accessor keys are in any domain that is not of type table, will be ignored
         if (
             domain_type != MetricDomainTypes.TABLE
@@ -387,7 +469,7 @@ Please check your config."""
             and len(list(accessor_keys)) > 0
         ):
             logger.warning(
-                "Accessor keys ignored since Metric Domain Type is not 'table"
+                'Accessor keys ignored since Metric Domain Type is not "table"'
             )
 
         if domain_type == MetricDomainTypes.TABLE:
@@ -413,59 +495,35 @@ Please check your config."""
                     )
             return data, compute_domain_kwargs, accessor_domain_kwargs
 
-        # If user has stated they want a column, checking if one is provided, and
         elif domain_type == MetricDomainTypes.COLUMN:
-            if "column" in compute_domain_kwargs:
-                accessor_domain_kwargs["column"] = compute_domain_kwargs.pop("column")
-            else:
-                # If column not given
+            if "column" not in compute_domain_kwargs:
                 raise GreatExpectationsError(
                     "Column not provided in compute_domain_kwargs"
                 )
 
-        # Else, if column pair values requested
+            accessor_domain_kwargs["column"] = compute_domain_kwargs.pop("column")
+
         elif domain_type == MetricDomainTypes.COLUMN_PAIR:
-            # Ensuring column_A and column_B parameters provided
-            if (
+            if not (
                 "column_A" in compute_domain_kwargs
                 and "column_B" in compute_domain_kwargs
             ):
-                accessor_domain_kwargs["column_A"] = compute_domain_kwargs.pop(
-                    "column_A"
-                )
-                accessor_domain_kwargs["column_B"] = compute_domain_kwargs.pop(
-                    "column_B"
-                )
-            else:
                 raise GreatExpectationsError(
                     "column_A or column_B not found within compute_domain_kwargs"
                 )
 
-        # Checking if table or identity or other provided, column is not specified. If it is, warning the user
+            accessor_domain_kwargs["column_A"] = compute_domain_kwargs.pop("column_A")
+            accessor_domain_kwargs["column_B"] = compute_domain_kwargs.pop("column_B")
+
         elif domain_type == MetricDomainTypes.MULTICOLUMN:
-            if "columns" in compute_domain_kwargs:
-                # If columns exist
-                accessor_domain_kwargs["columns"] = compute_domain_kwargs.pop("columns")
-
-        # Filtering if identity
-        elif domain_type == MetricDomainTypes.IDENTITY:
-
-            # If we would like our data to become a single column
-            if "column" in compute_domain_kwargs:
-                data = data.select(compute_domain_kwargs["column"])
-
-            # If we would like our data to now become a column pair
-            elif ("column_A" in compute_domain_kwargs) and (
-                "column_B" in compute_domain_kwargs
-            ):
-                data = data.select(
-                    compute_domain_kwargs["column_A"], compute_domain_kwargs["column_B"]
+            if "column_list" not in domain_kwargs:
+                raise ge_exceptions.GreatExpectationsError(
+                    "column_list not found within domain_kwargs"
                 )
-            else:
 
-                # If we would like our data to become a multicolumn
-                if "columns" in compute_domain_kwargs:
-                    data = data.select(compute_domain_kwargs["columns"])
+            accessor_domain_kwargs["column_list"] = compute_domain_kwargs.pop(
+                "column_list"
+            )
 
         return data, compute_domain_kwargs, accessor_domain_kwargs
 
@@ -544,8 +602,8 @@ Please check your config."""
             aggregates[domain_id]["ids"].append(metric_to_resolve.id)
         for aggregate in aggregates.values():
             compute_domain_kwargs = aggregate["domain_kwargs"]
-            df, _, _ = self.get_compute_domain(
-                compute_domain_kwargs, domain_type=MetricDomainTypes.IDENTITY.value
+            df = self.get_domain_records(
+                domain_kwargs=compute_domain_kwargs,
             )
             assert len(aggregate["column_aggregates"]) == len(aggregate["ids"])
             condition_ids = []
