@@ -1,12 +1,19 @@
-from .column_aggregate_metric import (
-    ColumnMetricProvider,
+from .meta_metric_provider import (  # isort:skip
+    MetaMetricProvider,
+    DeprecatedMetaMetricProvider,
+)
+from .column_aggregate_metric_provider import (
+    ColumnMetricProvider,  # This class name is being deprecated (use "ColumnAggregateMetricProvider" going forward).
+)
+from .column_aggregate_metric_provider import (
+    ColumnAggregateMetricProvider,
     column_aggregate_partial,
     column_aggregate_value,
 )
 from .column_aggregate_metrics import *
 from .column_map_metrics import *
 from .column_pair_map_metrics import *
-from .map_metric import (
+from .map_metric_provider import (
     ColumnMapMetricProvider,
     MapMetricProvider,
     column_condition_partial,
@@ -21,4 +28,5 @@ from .metric_provider import (
     metric_partial,
     metric_value,
 )
+from .multicolumn_map_metrics import *
 from .table_metrics import *
