@@ -1,13 +1,8 @@
-from typing import List, Optional, Union
+from typing import List, Optional
 
 from great_expectations.execution_engine.execution_engine import MetricDomainTypes
-from great_expectations.rule_based_profiler.domain_builder.domain import Domain
-from great_expectations.rule_based_profiler.domain_builder.domain_builder import (
-    DomainBuilder,
-)
-from great_expectations.rule_based_profiler.parameter_builder.parameter_container import (
-    ParameterContainer,
-)
+from great_expectations.rule_based_profiler.domain_builder import Domain, DomainBuilder
+from great_expectations.rule_based_profiler.parameter_builder import ParameterContainer
 from great_expectations.validator.validation_graph import MetricConfiguration
 
 
@@ -19,8 +14,6 @@ class ColumnDomainBuilder(DomainBuilder):
         """
         Obtains and returns domains for all columns of a table.
         """
-        # TODO: <Alex>It is error prone to have to specify "batch_id" in two, only loosely related, places in the code.
-        #  It will be useful to improve the architecture so as to guide the developer for a more consistent way.</Alex>
         batch_id: str = self.get_batch_id(variables=variables)
         table_column_names: List[str] = self.get_validator(
             variables=variables
@@ -41,7 +34,6 @@ class ColumnDomainBuilder(DomainBuilder):
                 domain_type=MetricDomainTypes.COLUMN,
                 domain_kwargs={
                     "column": column_name,
-                    "batch_id": batch_id,
                 },
             )
             for column_name in table_column_names
