@@ -1,13 +1,8 @@
 from typing import List, Optional
 
 from great_expectations.execution_engine.execution_engine import MetricDomainTypes
-from great_expectations.rule_based_profiler.domain_builder.domain import Domain
-from great_expectations.rule_based_profiler.domain_builder.domain_builder import (
-    DomainBuilder,
-)
-from great_expectations.rule_based_profiler.parameter_builder.parameter_container import (
-    ParameterContainer,
-)
+from great_expectations.rule_based_profiler.domain_builder import Domain, DomainBuilder
+from great_expectations.rule_based_profiler.parameter_builder import ParameterContainer
 
 
 class TableDomainBuilder(DomainBuilder):
