@@ -1,4 +1,5 @@
 import copy
+import json
 from typing import Dict, List, Optional, Tuple
 
 from great_expectations.core.id_dict import IDDict
@@ -25,6 +26,12 @@ class MetricConfiguration:
             metric_dependencies = dict()
         self.metric_dependencies = metric_dependencies
 
+    def __repr__(self):
+        return json.dumps(self.to_json_dict(), indent=2)
+
+    def __str__(self):
+        return self.__repr__()
+
     @property
     def metric_name(self):
         return self._metric_name
@@ -39,11 +46,11 @@ class MetricConfiguration:
 
     @property
     def metric_domain_kwargs_id(self):
-        return self._metric_domain_kwargs.to_id()
+        return self.metric_domain_kwargs.to_id()
 
     @property
     def metric_value_kwargs_id(self):
-        return self._metric_value_kwargs.to_id()
+        return self.metric_value_kwargs.to_id()
 
     @property
     def id(self) -> Tuple[str, str, str]:
@@ -53,6 +60,17 @@ class MetricConfiguration:
             self.metric_value_kwargs_id,
         )
 
+    def to_json_dict(self) -> dict:
+        json_dict: dict = {
+            "metric_name": self.metric_name,
+            "metric_domain_kwargs": self.metric_domain_kwargs,
+            "metric_domain_kwargs_id": self.metric_domain_kwargs_id,
+            "metric_value_kwargs": self.metric_value_kwargs,
+            "metric_value_kwargs_id": self.metric_value_kwargs_id,
+            "id": self.id,
+        }
+        return json_dict
+
 
 class MetricEdge:
     def __init__(self, left: MetricConfiguration, right: Optional[MetricConfiguration]):
