@@ -31,7 +31,7 @@ def titanic_sqlite_db_file(sa, tmp_path_factory):
     db_path = os.path.join(temp_dir, "titanic.db")
     shutil.copy(fixture_db_path, db_path)
 
-    engine = sa.create_engine("sqlite:///{}".format(db_path), pool_recycle=3600)
+    engine = sa.create_engine(f"sqlite:///{db_path}", pool_recycle=3600)
     assert engine.execute("select count(*) from titanic").fetchall()[0] == (1313,)
     return db_path
 
@@ -46,7 +46,7 @@ def test_cli_init_on_new_project(
 
     database_path = os.path.join(project_dir, "titanic.db")
     shutil.copy(titanic_sqlite_db_file, database_path)
-    engine = sa.create_engine("sqlite:///{}".format(database_path), pool_recycle=3600)
+    engine = sa.create_engine(f"sqlite:///{database_path}", pool_recycle=3600)
 
     inspector = sa.inspect(engine)
 
@@ -208,7 +208,7 @@ def test_cli_init_on_new_project_extra_whitespace_in_url(
 
     database_path = os.path.join(project_dir, "titanic.db")
     shutil.copy(titanic_sqlite_db_file, database_path)
-    engine = sa.create_engine("sqlite:///{}".format(database_path), pool_recycle=3600)
+    engine = sa.create_engine(f"sqlite:///{database_path}", pool_recycle=3600)
     engine_url_with_added_whitespace = "    " + str(engine.url) + "  "
 
     inspector = sa.inspect(engine)
@@ -311,7 +311,7 @@ def test_init_on_existing_project_with_no_datasources_should_continue_init_flow_
     assert not context.list_expectation_suites()
 
     runner = CliRunner(mix_stderr=False)
-    url = "sqlite:///{}".format(titanic_sqlite_db_file)
+    url = f"sqlite:///{titanic_sqlite_db_file}"
 
     inspector = sa.inspect(sa.create_engine(url))
 
@@ -415,9 +415,7 @@ def initialized_sqlite_project(
     """This is an initialized project through the CLI."""
     project_dir = str(tmp_path_factory.mktemp("my_rad_project"))
 
-    engine = sa.create_engine(
-        "sqlite:///{}".format(titanic_sqlite_db_file), pool_recycle=3600
-    )
+    engine = sa.create_engine(f"sqlite:///{titanic_sqlite_db_file}", pool_recycle=3600)
 
     inspector = sa.inspect(engine)
 
