@@ -1,13 +1,14 @@
 try:
     from unittest import mock
 except ImportError:
-    import mock
+    from unittest import mock
+
 import pandas as pd
 import pytest
 
 from great_expectations.dataset import MetaSqlAlchemyDataset, SqlAlchemyDataset
+from great_expectations.self_check.util import get_dataset
 from great_expectations.util import is_library_loadable
-from tests.test_utils import get_dataset
 
 
 @pytest.fixture
@@ -32,7 +33,12 @@ def custom_dataset(sa):
             )
 
             mode = self.engine.execute(mode_query).scalar()
-            return {"success": mode == 0, "result": {"observed_value": mode,}}
+            return {
+                "success": mode == 0,
+                "result": {
+                    "observed_value": mode,
+                },
+            }
 
         @MetaSqlAlchemyDataset.column_aggregate_expectation
         def broken_aggregate_expectation(self, column):
@@ -312,3 +318,51 @@ def test_dataset_attempt_allowing_relative_error_when_redshift_library_not_insta
 
     assert isinstance(dataset, SqlAlchemyDataset)
     assert dataset.attempt_allowing_relative_error() is False
+
+
+def test_expect_compound_columns_to_be_unique(sa):
+    engine = sa.create_engine("sqlite://")
+
+    data = pd.DataFrame(
+        {
+            "col1": [1, 2, 3, 1, 2, 3, None, None],
+            "col2": [1, 2, 2, 2, 2, 3, None, None],
+            "col3": [1, 1, 2, 2, 3, 2, None, None],
+            "col4": [1, None, 2, 2, None, None, None, None],
+        }
+    )
+
+    data.to_sql(name="test_sql_data", con=engine, index=False)
+    dataset = SqlAlchemyDataset("test_sql_data", engine=engine)
+
+    assert not dataset.expect_compound_columns_to_be_unique(["col1", "col2"]).success
+    assert not dataset.expect_compound_columns_to_be_unique(["col2", "col3"]).success
+    assert not dataset.expect_compound_columns_to_be_unique(["col1", "col3"]).success
+    assert dataset.expect_compound_columns_to_be_unique(
+        ["col1", "col2", "col3"]
+    ).success
+    assert not dataset.expect_compound_columns_to_be_unique(
+        ["col1", "col2", "col4"],
+        ignore_row_if="any_value_is_missing",
+    ).success
+    assert dataset.expect_compound_columns_to_be_unique(
+        ["col1", "col2", "col4"]
+    ).success
+
+
+def test_expect_compound_columns_to_be_unique_with_no_rows(sa):
+    engine = sa.create_engine("sqlite://")
+
+    data = pd.DataFrame(
+        {
+            "col1": [],
+            "col2": [],
+            "col3": [],
+            "col4": [],
+        }
+    )
+
+    data.to_sql(name="test_sql_data", con=engine, index=False)
+    dataset = SqlAlchemyDataset("test_sql_data", engine=engine)
+
+    assert dataset.expect_compound_columns_to_be_unique(["col1", "col2"]).success
