@@ -30,10 +30,12 @@ def test_self_check(basic_datasource):
     assert test_runtime_data_connector.self_check() == {
         "class_name": "RuntimeDataConnector",
         "data_asset_count": 0,
-        "example_data_asset_names": [],
         "data_assets": {},
-        "unmatched_data_reference_count": 0,
+        "example_data_asset_names": [],
         "example_unmatched_data_references": [],
+        "note": "RuntimeDataConnector will not have data_asset_names until they are "
+        "passed in through RuntimeBatchRequest",
+        "unmatched_data_reference_count": 0,
     }
 
 
@@ -544,7 +546,7 @@ def test__generate_batch_spec_parameters_from_batch_definition(
         basic_datasource.data_connectors["test_runtime_data_connector"]
     )
 
-    expected_batch_spec_parameters: dict = {}
+    expected_batch_spec_parameters: dict = {"data_asset_name": "my_data_asset"}
 
     # noinspection PyProtectedMember
     batch_spec_parameters: dict = test_runtime_data_connector._generate_batch_spec_parameters_from_batch_definition(
@@ -583,7 +585,7 @@ def test__build_batch_spec(basic_datasource):
         },
     )
     assert type(batch_spec) == RuntimeDataBatchSpec
-    assert set(batch_spec.keys()) == {"batch_data"}
+    assert set(batch_spec.keys()) == {"batch_data", "data_asset_name"}
     assert batch_spec["batch_data"].shape == (10, 1)
 
     batch_spec: BatchSpec = test_runtime_data_connector.build_batch_spec(
