@@ -7,14 +7,12 @@ import numpy as np
 import pandas as pd
 import pytest
 
-import great_expectations.exceptions.exceptions as ge_exceptions
+import great_expectations.exceptions as ge_exceptions
 from great_expectations.core.batch_spec import (
     PathBatchSpec,
     RuntimeDataBatchSpec,
     S3BatchSpec,
 )
-from great_expectations.exceptions import GreatExpectationsError
-from great_expectations.exceptions.metric_exceptions import MetricProviderError
 from great_expectations.execution_engine import SparkDFExecutionEngine
 from great_expectations.execution_engine.execution_engine import MetricDomainTypes
 from great_expectations.self_check.util import build_spark_engine
@@ -26,11 +24,12 @@ try:
     pyspark = pytest.importorskip("pyspark")
     # noinspection PyPep8Naming
     import pyspark.sql.functions as F
-    from pyspark.sql.types import IntegerType, Row, StringType
+    from pyspark.sql.types import IntegerType, LongType, Row, StringType
 except ImportError:
     pyspark = None
     F = None
     IntegerType = None
+    LongType = None
     StringType = None
     Row = None
 
@@ -140,6 +139,252 @@ def test_reader_fn_parameters(
     assert test_sparkdf_with_no_header_param.head() == Row(_c0="x", _c1="y")
 
 
+def test_get_domain_records_with_column_domain(
+    spark_session, basic_spark_df_execution_engine
+):
+    pd_df = pd.DataFrame(
+        {"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]}
+    )
+    df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in pd_df.to_records(index=False)
+        ],
+        pd_df.columns.tolist(),
+    )
+    engine = basic_spark_df_execution_engine
+    engine.load_batch_data(batch_id="1234", batch_data=df)
+    data = engine.get_domain_records(
+        domain_kwargs={
+            "column": "a",
+            "row_condition": 'col("b")<5',
+            "condition_parser": "great_expectations__experimental__",
+        }
+    )
+
+    expected_column_pd_df = pd_df.iloc[:3]
+    expected_column_df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in expected_column_pd_df.to_records(index=False)
+        ],
+        expected_column_pd_df.columns.tolist(),
+    )
+
+    assert dataframes_equal(
+        data, expected_column_df
+    ), "Data does not match after getting full access compute domain"
+
+
+def test_get_domain_records_with_column_pair_domain(
+    spark_session, basic_spark_df_execution_engine
+):
+    pd_df = pd.DataFrame(
+        {
+            "a": [1, 2, 3, 4, 5, 6],
+            "b": [2, 3, 4, 5, None, 6],
+            "c": [1, 2, 3, 4, 5, None],
+        }
+    )
+    df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in pd_df.to_records(index=False)
+        ],
+        pd_df.columns.tolist(),
+    )
+    engine = basic_spark_df_execution_engine
+    engine.load_batch_data(batch_id="1234", batch_data=df)
+    data = engine.get_domain_records(
+        domain_kwargs={
+            "column_A": "a",
+            "column_B": "b",
+            "row_condition": 'col("b")>2',
+            "condition_parser": "great_expectations__experimental__",
+            "ignore_row_if": "either_value_is_missing",
+        }
+    )
+
+    expected_column_pair_pd_df = pd.DataFrame(
+        {"a": [2, 3, 4, 6], "b": [3.0, 4.0, 5.0, 6.0], "c": [2.0, 3.0, 4.0, None]}
+    )
+    expected_column_pair_df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in expected_column_pair_pd_df.to_records(index=False)
+        ],
+        expected_column_pair_pd_df.columns.tolist(),
+    )
+
+    assert dataframes_equal(
+        data, expected_column_pair_df
+    ), "Data does not match after getting full access compute domain"
+
+    pd_df = pd.DataFrame(
+        {
+            "a": [1, 2, 3, 4, 5, 6],
+            "b": [2, 3, 4, 5, None, 6],
+            "c": [1, 2, 3, 4, 5, None],
+        }
+    )
+    df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in pd_df.to_records(index=False)
+        ],
+        pd_df.columns.tolist(),
+    )
+    engine = basic_spark_df_execution_engine
+    engine.load_batch_data(batch_id="1234", batch_data=df)
+    data = engine.get_domain_records(
+        domain_kwargs={
+            "column_A": "b",
+            "column_B": "c",
+            "row_condition": 'col("a")<6',
+            "condition_parser": "great_expectations__experimental__",
+            "ignore_row_if": "either_value_is_missing",
+        }
+    )
+    for column_name in data.columns:
+        data = data.withColumn(column_name, data[column_name].cast(LongType()))
+
+    expected_column_pair_pd_df = pd.DataFrame(
+        {"a": [1, 2, 3, 4], "b": [2, 3, 4, 5], "c": [1, 2, 3, 4]}
+    )
+    expected_column_pair_df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in expected_column_pair_pd_df.to_records(index=False)
+        ],
+        expected_column_pair_pd_df.columns.tolist(),
+    )
+
+    assert dataframes_equal(
+        data, expected_column_pair_df
+    ), "Data does not match after getting full access compute domain"
+
+
+def test_get_domain_records_with_multicolumn_domain(
+    spark_session, basic_spark_df_execution_engine
+):
+    pd_df = pd.DataFrame(
+        {
+            "a": [1, 2, 3, 4, None, 5],
+            "b": [2, 3, 4, 5, 6, 7],
+            "c": [1, 2, 3, 4, None, 6],
+        }
+    )
+    df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in pd_df.to_records(index=False)
+        ],
+        pd_df.columns.tolist(),
+    )
+    engine = basic_spark_df_execution_engine
+    engine.load_batch_data(batch_id="1234", batch_data=df)
+    data = engine.get_domain_records(
+        domain_kwargs={
+            "column_list": ["a", "c"],
+            "row_condition": 'col("b")>2',
+            "condition_parser": "great_expectations__experimental__",
+            "ignore_row_if": "all_values_are_missing",
+        }
+    )
+    for column_name in data.columns:
+        data = data.withColumn(column_name, data[column_name].cast(LongType()))
+
+    expected_multicolumn_pd_df = pd.DataFrame(
+        {"a": [2, 3, 4, 5], "b": [3, 4, 5, 7], "c": [2, 3, 4, 6]}, index=[0, 1, 2, 4]
+    )
+    expected_multicolumn_df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in expected_multicolumn_pd_df.to_records(index=False)
+        ],
+        expected_multicolumn_pd_df.columns.tolist(),
+    )
+    engine = basic_spark_df_execution_engine
+    engine.load_batch_data(batch_id="1234", batch_data=expected_multicolumn_df)
+
+    assert dataframes_equal(
+        data, expected_multicolumn_df
+    ), "Data does not match after getting full access compute domain"
+
+    pd_df = pd.DataFrame(
+        {
+            "a": [1, 2, 3, 4, 5, 6],
+            "b": [2, 3, 4, 5, None, 6],
+            "c": [1, 2, 3, 4, 5, None],
+        }
+    )
+    df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in pd_df.to_records(index=False)
+        ],
+        pd_df.columns.tolist(),
+    )
+    engine = basic_spark_df_execution_engine
+    engine.load_batch_data(batch_id="1234", batch_data=df)
+    data = engine.get_domain_records(
+        domain_kwargs={
+            "column_list": ["b", "c"],
+            "row_condition": 'col("a")<6',
+            "condition_parser": "great_expectations__experimental__",
+            "ignore_row_if": "any_value_is_missing",
+        }
+    )
+    for column_name in data.columns:
+        data = data.withColumn(column_name, data[column_name].cast(LongType()))
+
+    expected_multicolumn_pd_df = pd.DataFrame(
+        {"a": [1, 2, 3, 4], "b": [2, 3, 4, 5], "c": [1, 2, 3, 4]}
+    )
+
+    expected_multicolumn_df = spark_session.createDataFrame(
+        [
+            tuple(
+                None if isinstance(x, (float, int)) and np.isnan(x) else x
+                for x in record.tolist()
+            )
+            for record in expected_multicolumn_pd_df.to_records(index=False)
+        ],
+        expected_multicolumn_pd_df.columns.tolist(),
+    )
+
+    assert dataframes_equal(
+        data, expected_multicolumn_df
+    ), "Data does not match after getting full access compute domain"
+
+
 def test_get_compute_domain_with_no_domain_kwargs(
     spark_session, basic_spark_df_execution_engine
 ):
@@ -968,20 +1213,6 @@ def test_get_compute_domain_with_column_pair(
         "column_B": "b",
     }, "Accessor kwargs have been modified"
 
-    data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
-        domain_kwargs={"column_A": "a", "column_B": "b"}, domain_type="identity"
-    )
-
-    # Ensuring that with no domain nothing happens to the data itself
-    assert dataframes_equal(
-        data, df
-    ), "Data does not match after getting compute domain"
-    assert compute_kwargs == {
-        "column_A": "a",
-        "column_B": "b",
-    }, "Compute domain kwargs should not be modified"
-    assert accessor_kwargs == {}, "Accessor kwargs have been modified"
-
 
 # Testing for only untested use case - multicolumn
 def test_get_compute_domain_with_multicolumn(
@@ -997,7 +1228,7 @@ def test_get_compute_domain_with_multicolumn(
     df = engine.dataframe
 
     data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
-        domain_kwargs={"columns": ["a", "b", "c"]}, domain_type="multicolumn"
+        domain_kwargs={"column_list": ["a", "b", "c"]}, domain_type="multicolumn"
     )
 
     # Ensuring that with no domain nothing happens to the data itself
@@ -1006,24 +1237,9 @@ def test_get_compute_domain_with_multicolumn(
     ), "Data does not match after getting compute domain"
     assert compute_kwargs == {}, "Compute domain kwargs should be empty"
     assert accessor_kwargs == {
-        "columns": ["a", "b", "c"]
+        "column_list": ["a", "b", "c"]
     }, "Accessor kwargs have been modified"
 
-    # Checking for identity
-    engine.load_batch_data(batch_data=df, batch_id="1234")
-    data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
-        domain_kwargs={"columns": ["a", "b", "c"]}, domain_type="identity"
-    )
-
-    # Ensuring that with no domain nothing happens to the data itself
-    assert dataframes_equal(
-        data, df
-    ), "Data does not match after getting compute domain"
-    assert compute_kwargs == {
-        "columns": ["a", "b", "c"]
-    }, "Compute domain kwargs should not change for identity domain"
-    assert accessor_kwargs == {}, "Accessor kwargs have been modified"
-
 
 # Testing whether compute domain is properly calculated, but this time obtaining a column
 def test_get_compute_domain_with_column_domain_alt(
@@ -1051,7 +1267,7 @@ def test_get_compute_domain_with_column_domain_alt(
 
 
 # Using an unmeetable row condition to see if empty dataset will result in errors
-def test_get_compute_domain_with_row_condition_alt(
+def test_get_domain_records_with_row_condition_alt(
     spark_session, basic_spark_df_execution_engine
 ):
     engine: SparkDFExecutionEngine = build_spark_engine(
@@ -1067,9 +1283,11 @@ def test_get_compute_domain_with_row_condition_alt(
     # Loading batch data
     engine.load_batch_data(batch_data=df, batch_id="1234")
 
-    data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
-        domain_kwargs={"row_condition": "b > 2", "condition_parser": "spark"},
-        domain_type="identity",
+    data = engine.get_domain_records(
+        domain_kwargs={
+            "row_condition": "b > 2",
+            "condition_parser": "spark",
+        }
     )
 
     # Ensuring data has been properly queried
@@ -1077,15 +1295,9 @@ def test_get_compute_domain_with_row_condition_alt(
         data, expected_df
     ), "Data does not match after getting compute domain"
 
-    # Ensuring compute kwargs have not been modified
-    assert (
-        "row_condition" in compute_kwargs.keys()
-    ), "Row condition should be located within compute kwargs"
-    assert accessor_kwargs == {}, "Accessor kwargs have been modified"
-
 
 # What happens when we filter such that no value meets the condition?
-def test_get_compute_domain_with_unmeetable_row_condition_alt(
+def test_get_domain_records_with_unmeetable_row_condition_alt(
     spark_session, basic_spark_df_execution_engine
 ):
     engine: SparkDFExecutionEngine = build_spark_engine(
@@ -1101,23 +1313,19 @@ def test_get_compute_domain_with_unmeetable_row_condition_alt(
     # Loading batch data
     engine.load_batch_data(batch_data=df, batch_id="1234")
 
-    data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
-        domain_kwargs={"row_condition": "b > 24", "condition_parser": "spark"},
-        domain_type="identity",
+    data = engine.get_domain_records(
+        domain_kwargs={
+            "row_condition": "b > 24",
+            "condition_parser": "spark",
+        }
     )
     # Ensuring data has been properly queried
     assert dataframes_equal(
         data, expected_df
     ), "Data does not match after getting compute domain"
 
-    # Ensuring compute kwargs have not been modified
-    assert (
-        "row_condition" in compute_kwargs.keys()
-    ), "Row condition should be located within compute kwargs"
-    assert accessor_kwargs == {}, "Accessor kwargs have been modified"
-
     # Ensuring errors for column and column_ pair domains are caught
-    with pytest.raises(GreatExpectationsError):
+    with pytest.raises(ge_exceptions.GreatExpectationsError):
         # noinspection PyUnusedLocal
         data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
             domain_kwargs={
@@ -1126,7 +1334,7 @@ def test_get_compute_domain_with_unmeetable_row_condition_alt(
             },
             domain_type="column",
         )
-    with pytest.raises(GreatExpectationsError) as g:
+    with pytest.raises(ge_exceptions.GreatExpectationsError) as g:
         # noinspection PyUnusedLocal
         data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
             domain_kwargs={
@@ -1176,26 +1384,19 @@ def test_get_compute_domain_with_ge_experimental_condition_parser(
     ), "Row condition should be located within compute kwargs"
     assert accessor_kwargs == {"column": "b"}, "Accessor kwargs have been modified"
 
-    # Should react differently for domain type identity
-    data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
+    # Should react same for get_domain_records()
+    data = engine.get_domain_records(
         domain_kwargs={
             "column": "b",
             "row_condition": 'col("b") == 2',
             "condition_parser": "great_expectations__experimental__",
-        },
-        domain_type="identity",
+        }
     )
     # Ensuring data has been properly queried
     assert dataframes_equal(
-        data, expected_df.select("b")
+        data, expected_df
     ), "Data does not match after getting compute domain"
 
-    # Ensuring compute kwargs have not been modified
-    assert (
-        "row_condition" in compute_kwargs.keys()
-    ), "Row condition should be located within compute kwargs"
-    assert accessor_kwargs == {}, "Accessor kwargs have been modified"
-
 
 def test_get_compute_domain_with_nonexistent_condition_parser(
     spark_session, basic_spark_df_execution_engine
@@ -1213,14 +1414,13 @@ def test_get_compute_domain_with_nonexistent_condition_parser(
     engine.load_batch_data(batch_data=df, batch_id="1234")
 
     # Expect GreatExpectationsError because parser doesn't exist
-    with pytest.raises(GreatExpectationsError):
+    with pytest.raises(ge_exceptions.GreatExpectationsError):
         # noinspection PyUnusedLocal
-        data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
+        data = engine.get_domain_records(
             domain_kwargs={
                 "row_condition": "b > 24",
                 "condition_parser": "nonexistent",
             },
-            domain_type=MetricDomainTypes.IDENTITY,
         )
 
 
@@ -1258,7 +1458,7 @@ def test_resolve_metric_bundle_with_nonexistent_metric(
     )
 
     # Ensuring a metric provider error is raised if metric does not exist
-    with pytest.raises(MetricProviderError) as e:
+    with pytest.raises(ge_exceptions.MetricProviderError) as e:
         # noinspection PyUnusedLocal
         res = engine.resolve_metrics(
             metrics_to_resolve=(
