@@ -1,7 +1,7 @@
 import jsonschema
 import pytest
 
-from great_expectations.core import ExpectationSuite
+from great_expectations.core.expectation_suite import ExpectationSuite
 from great_expectations.profile.base import ProfilerTypeMapping
 from great_expectations.profile.json_schema_profiler import JsonSchemaProfiler
 
@@ -12,7 +12,10 @@ def simple_schema():
         "$id": "https://example.com/address.schema.json",
         "$schema": "http://json-schema.org/draft-07/schema#",
         "type": "object",
-        "properties": {"first_name": {"type": "string"}, "age": {"type": "integer"},},
+        "properties": {
+            "first_name": {"type": "string"},
+            "age": {"type": "integer"},
+        },
     }
 
 
@@ -48,7 +51,16 @@ def boolean_types_schema():
         "type": "object",
         "properties": {
             "active": {"type": "boolean"},
-            "optional": {"anyOf": [{"type": "boolean",}, {"type": "null",}]},
+            "optional": {
+                "anyOf": [
+                    {
+                        "type": "boolean",
+                    },
+                    {
+                        "type": "null",
+                    },
+                ]
+            },
         },
     }
 
@@ -62,13 +74,20 @@ def enum_types_schema():
         "properties": {
             "shirt-size": {"enum": ["XS", "S", "M", "XL", "XXL"]},
             "optional-color": {
-                "anyOf": [{"enum": ["red", "green", "blue"],}, {"type": "null"}],
+                "anyOf": [
+                    {
+                        "enum": ["red", "green", "blue"],
+                    },
+                    {"type": "null"},
+                ],
             },
             "optional-hat": {
                 "type": ["string", "null"],
                 "enum": ["red", "green", "blue"],
             },
-            "optional-answer": {"enum": ["yes", "no", None],},
+            "optional-answer": {
+                "enum": ["yes", "no", None],
+            },
         },
     }
 
@@ -94,7 +113,15 @@ def string_lengths_schema():
             "name-no-max": {"type": "string", "minLength": 1},
             "password-max-33": {"type": "string", "maxLength": 33},
             "optional-min-1": {
-                "anyOf": [{"type": "string", "minLength": 1,}, {"type": "null",}]
+                "anyOf": [
+                    {
+                        "type": "string",
+                        "minLength": 1,
+                    },
+                    {
+                        "type": "null",
+                    },
+                ]
             },
         },
     }
@@ -125,7 +152,15 @@ def integer_ranges_schema():
                 "exclusiveMaximum": 6,
             },
             "optional-min-1": {
-                "anyOf": [{"type": "integer", "minimum": 1,}, {"type": "null",}]
+                "anyOf": [
+                    {
+                        "type": "integer",
+                        "minimum": 1,
+                    },
+                    {
+                        "type": "null",
+                    },
+                ]
             },
         },
     }
@@ -156,7 +191,15 @@ def number_ranges_schema():
                 "exclusiveMaximum": 6.5,
             },
             "optional-min-half": {
-                "anyOf": [{"type": "number", "minimum": 0.5,}, {"type": "null",}]
+                "anyOf": [
+                    {
+                        "type": "number",
+                        "minimum": 0.5,
+                    },
+                    {
+                        "type": "null",
+                    },
+                ]
             },
         },
     }
@@ -401,7 +444,10 @@ def test_profile_enum_schema(empty_data_context, enum_types_schema):
         {
             "meta": {},
             "expectation_type": "expect_column_values_to_be_in_set",
-            "kwargs": {"column": "optional-answer", "value_set": ["yes", "no"],},
+            "kwargs": {
+                "column": "optional-answer",
+                "value_set": ["yes", "no"],
+            },
         },
     ]
     context = empty_data_context
@@ -760,7 +806,10 @@ def test_profile_integer_ranges_schema(empty_data_context, integer_ranges_schema
             "meta": {},
         },
         {
-            "kwargs": {"column": "optional-min-1", "min_value": 1,},
+            "kwargs": {
+                "column": "optional-min-1",
+                "min_value": 1,
+            },
             "expectation_type": "expect_column_values_to_be_between",
             "meta": {},
         },
@@ -982,7 +1031,10 @@ def test_profile_number_ranges_schema(empty_data_context, number_ranges_schema):
             "meta": {},
         },
         {
-            "kwargs": {"column": "optional-min-half", "min_value": 0.5,},
+            "kwargs": {
+                "column": "optional-min-half",
+                "min_value": 0.5,
+            },
             "expectation_type": "expect_column_values_to_be_between",
             "meta": {},
         },
@@ -1203,7 +1255,10 @@ def test_null_fields_schema(empty_data_context, null_fields_schema):
         {
             "meta": {},
             "expectation_type": "expect_column_values_to_be_in_set",
-            "kwargs": {"column": "enum-or-null", "value_set": ["a", "b", "c"],},
+            "kwargs": {
+                "column": "enum-or-null",
+                "value_set": ["a", "b", "c"],
+            },
         },
     ]
     context = empty_data_context
